module DockerNginxProxy
  class Cli < Clamp::Command

    parameter "CONTAINER_NAME", "docker container name", :attribute_name => :container_name
    parameter "MAPPING ...", "domain:port=port mapping", :attribute_name => :encoded_mappings

    def execute

      docker_port_mappings = Docker.new.get_mappings(container_name)
      mappings = _convert_mapping_to_hash(encoded_mappings)
      mappings.map do |domain_port, container_port|
        docker_port = docker_port_mappings[container_port]
        raise "No docker port found for container port #{container_port}. Mappings: #{docker_port_mappings}" unless docker_port
        mappings[domain_port] = docker_port
      end
      Nginx.new.install_proxy(container_name, mappings)
    end

    def _convert_mapping_to_hash(encoded_mappings)
      mappings = {}
      encoded_mappings.each do |encoded_mapping|
        domain_port, container_port = encoded_mapping.split('=', 2)
        raise 'Each mapping needs to follow format: "domain[:port]=container_port". `' + encoded_mapping + '` does not follow it.' unless container_port
        mappings[domain_port] = container_port.to_i
      end
      mappings
    end
  end
end
